# Generated by Django 2.2.3 on 2021-02-21 02:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('epayco_django', '0004_add_length_to_transaction_fields'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='customer_doctype',
            field=models.CharField(max_length=12),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='customer_document',
            field=models.CharField(max_length=64),
        ),
    ]
