# Generated by Django 2.2.3 on 2020-09-10 00:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('epayco_django', '0002_transaction_id_max_length'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='response_reason_text',
            field=models.CharField(max_length=256),
        ),
    ]
