# Generated by Django 2.2.8 on 2020-05-18 15:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('epayco_django', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='extra1',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='extra10',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='extra2',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='extra3',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='extra4',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='extra5',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='extra6',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='extra7',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='extra8',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='extra9',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='flag_code',
            field=models.CharField(blank=True, choices=[('1001', 'Duplicate Transaction'), ('1002', 'Invalid Sign'), ('1003', 'Test transacción on non test environment')], default='', max_length=4),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='flag_info',
            field=models.CharField(blank=True, default='', max_length=100),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='transaction_id',
            field=models.CharField(max_length=64),
        ),
    ]
