# Generated by Django 2.2.3 on 2021-02-21 02:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('epayco_django', '0003_extend_response_reason_text_length'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='approval_code',
            field=models.CharField(max_length=32),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='cod_response',
            field=models.CharField(max_length=32),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='cod_transaction_state',
            field=models.CharField(max_length=32),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='errorcode',
            field=models.CharField(max_length=32),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='franchise',
            field=models.CharField(max_length=32),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='response',
            field=models.CharField(max_length=32),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='transaction_state',
            field=models.CharField(max_length=32),
        ),
    ]
